## cdist-type__ccollect_source(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__ccollect_source - Manage ccollect sources

## 2. DESCRIPTION

This cdist type allows you to create or delete ccollect sources.

## 3. REQUIRED PARAMETERS

source
  The source from which to backup
destination
  The destination directory

## 4. OPTIONAL PARAMETERS

state
  present or absent, defaults to present
ccollectconf
  The CCOLLECT_CONF directory. Defaults to /etc/ccollect.

## 5. OPTIONAL MULTIPLE PARAMETERS

exclude
  Paths to exclude of backup

## 6. BOOLEAN PARAMETERS

verbose
  Whether to report backup verbosely

## 7. EXAMPLES

    __ccollect_source doc.ungleich.ch \
        --source doc.ungleich.ch:/ \
        --destination /backup/doc.ungleich.ch \
        --exclude '/proc/*' --exclude '/sys/*' \
        --verbose

## 8. SEE ALSO

- cdist-type(7)
- ccollect(1)
- http://www.nico.schottelius.org/software/ccollect/

## 9. COPYING

Copyright (C) 2014 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).